From 677b11428e37417ec9228023dd58747760a06f40 Mon Sep 17 00:00:00 2001
From: sjplimp <sjplimp@f3b2605a-c512-4ea7-a41b-209d697bcdaa>
Date: Thu, 30 Jan 2014 16:09:37 +0000
Subject: [PATCH] git-svn-id: svn://svn.icms.temple.edu/lammps-ro/trunk@11387
 f3b2605a-c512-4ea7-a41b-209d697bcdaa

---
 src/DIPOLE/pair_lj_cut_dipole_long.h  |  2 +-
 src/DIPOLE/pair_lj_long_dipole_long.h |  6 +-
 src/GPU/pair_sw_gpu.h                 | 34 ++--------
 src/KIM/pair_kim.cpp                  |  8 +--
 src/KIM/pair_kim.h                    | 19 +-----
 src/KSPACE/pair_lj_long_coul_long.h   |  4 +-
 src/KSPACE/pppm.h                     |  2 +-
 src/KSPACE/pppm_disp.h                |  6 ++
 src/KSPACE/pppm_old.h                 |  8 ++-
 src/MANYBODY/pair_comb3.cpp           |  6 +-
 src/MANYBODY/pair_comb3.h             | 62 ++++-------------
 src/MANYBODY/pair_lcbop.h             | 98 +++------------------------
 src/MANYBODY/pair_nb3b_harmonic.h     | 53 ++-------------
 src/MANYBODY/pair_tersoff_mod.h       | 25 +++----
 src/MISC/pair_nm_cut.h                | 66 +-----------------
 src/MOLECULE/pair_lj_cut_tip4p_cut.h  | 10 +--
 src/MOLECULE/pair_tip4p_cut.h         |  6 +-
 src/MPIIO/restart_mpiio.cpp           | 14 ++--
 src/MPIIO/restart_mpiio.h             | 30 ++++----
 src/REPLICA/verlet_split.h            |  2 +-
 src/pair.h                            |  6 +-
 src/read_data.h                       | 25 ++-----
 src/read_dump.h                       |  8 +--
 src/read_restart.cpp                  |  2 +-
 src/read_restart.h                    | 11 ++-
 src/replicate.h                       |  7 +-
 src/variable.h                        | 24 +++----
 src/velocity.h                        | 16 +----
 src/write_data.h                      |  8 ++-
 src/write_dump.h                      | 81 +---------------------
 src/write_restart.h                   | 11 +--
 31 files changed, 154 insertions(+), 506 deletions(-)

diff --git a/src/DIPOLE/pair_lj_cut_dipole_long.h b/src/DIPOLE/pair_lj_cut_dipole_long.h
index 91e7536576..a373cf2965 100755
--- a/src/DIPOLE/pair_lj_cut_dipole_long.h
+++ b/src/DIPOLE/pair_lj_cut_dipole_long.h
@@ -71,7 +71,7 @@ Self-explanatory.  Check the input script or data file.
 
 E: Pair dipole/long requires atom attributes q, mu, torque
 
-UNDOCUMENTED
+The atom style defined does not have these attributes.
 
 E: Cannot (yet) use 'electron' units with dipoles
 
diff --git a/src/DIPOLE/pair_lj_long_dipole_long.h b/src/DIPOLE/pair_lj_long_dipole_long.h
index 89a73eb36c..df14837bca 100755
--- a/src/DIPOLE/pair_lj_long_dipole_long.h
+++ b/src/DIPOLE/pair_lj_long_dipole_long.h
@@ -76,11 +76,11 @@ Self-explanatory.
 
 W: Using largest cut-off for lj/long/dipole/long long long
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Cut-offs missing in pair_style lj/long/dipole/long
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Coulombic cut not supported in pair_style lj/long/dipole/long
 
@@ -88,7 +88,7 @@ Must use long-range Coulombic interactions.
 
 E: Only one cut-off allowed when requesting all long
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Incorrect args for pair coefficients
 
diff --git a/src/GPU/pair_sw_gpu.h b/src/GPU/pair_sw_gpu.h
index b22cb86a38..6b49a4937e 100644
--- a/src/GPU/pair_sw_gpu.h
+++ b/src/GPU/pair_sw_gpu.h
@@ -51,42 +51,20 @@ class PairSWGPU : public PairSW {
 
 E: Insufficient memory on accelerator
 
-UNDOCUMENTED
+There is insufficient memory on one of the devices specified for the gpu
+package
 
 E: Pair style sw/gpu requires atom IDs
 
-UNDOCUMENTED
+This is a requirement to use this potential.
 
 E: Pair style sw/gpu requires newton pair off
 
-UNDOCUMENTED
+See the newton command.  This is a restriction to use this potential.
 
 E: All pair coeffs are not set
 
-UNDOCUMENTED
-
-U: Illegal ... command
-
-Self-explanatory.  Check the input script syntax and compare to the
-documentation for the command.  You can use -echo screen as a
-command-line option when running LAMMPS to see the offending line.
-
-U: Incorrect args for pair coefficients
-
-Self-explanatory.  Check the input script or data file.
-
-U: No matching element in ADP potential file
-
-The ADP potential file does not contain elements that match the
-requested elements.
-
-U: Cannot open ADP potential file %s
-
-The specified ADP potential file cannot be opened.  Check that the
-path and name are correct.
-
-U: Incorrect element names in ADP potential file
-
-The element names in the ADP file do not match those requested.
+All pair coefficients must be set in the data file or by the
+pair_coeff command before running a simulation.
 
 */
diff --git a/src/KIM/pair_kim.cpp b/src/KIM/pair_kim.cpp
index 3391925b7a..97ff4a536d 100644
--- a/src/KIM/pair_kim.cpp
+++ b/src/KIM/pair_kim.cpp
@@ -381,7 +381,7 @@ void PairKIM::init_style()
    // This is called for each "run ...", "minimize ...", etc. read from input
 
    if (domain->dimension != 3)
-      error->all(FLERR,"PairKIM only works with 3D problems.");
+      error->all(FLERR,"PairKIM only works with 3D problems");
 
    // set lmps_* bool flags
    set_lmps_flags();
@@ -979,7 +979,7 @@ void PairKIM::set_kim_model_has_flags()
 
    // get KIM API object representing the KIM Model only
    kimerror = mdl.model_info(kim_modelname);
-   kim_error(__LINE__,"KIM initialization failed.", kimerror);
+   kim_error(__LINE__,"KIM initialization failed", kimerror);
 
    // determine if the KIM Model can compute the total energy
    mdl.get_index((char*) "energy", &kimerror);
@@ -1007,7 +1007,7 @@ void PairKIM::set_kim_model_has_flags()
    kim_model_has_particleVirial = (kimerror == KIM_STATUS_OK);
    mdl.get_index((char*) "process_dEdr", &kimerror);
    kim_model_has_particleVirial = kim_model_has_particleVirial || 
-     (kimerror == KIM_STATUS_OK);
+     (kimerror == KIM_STATUS_OK)<;
    if (!kim_model_has_particleVirial) 
      error->warning(FLERR,"KIM Model does not provide `particleVirial'; "
                     "virial per atom will be zero");
@@ -1025,7 +1025,7 @@ void PairKIM::write_descriptor(char** test_descriptor_string)
 {
    // allocate memory
    if (*test_descriptor_string != 0) 
-     error->all(FLERR, "test_descriptor_string already allocated.");
+     error->all(FLERR, "test_descriptor_string already allocated");
    // assuming 75 lines at 100 characters each (should be plenty)
    *test_descriptor_string = new char[100*75]; 
    // initialize
diff --git a/src/KIM/pair_kim.h b/src/KIM/pair_kim.h
index 307c7a9e03..222e98926b 100644
--- a/src/KIM/pair_kim.h
+++ b/src/KIM/pair_kim.h
@@ -170,7 +170,7 @@ E: Invalid args for non-hybrid pair coefficients
 
 E: PairKIM only works with 3D problems.
 
-UNDOCUMENTED
+This is a current limitation.
 
 E: All pair coeffs are not set
 
@@ -207,21 +207,8 @@ W: KIM Model does not provide `particleVirial'; virial per atom will be zero
 
 Self-explanatory.
 
-E: test_descriptor_string already allocated.
+E: Test_descriptor_string already allocated.
 
-UNDOCUMENTED
-
-U: PairKIM only works with 3D problems
-
-The KIM API does not explicitly support anything other than 3D problems
-
-U: Internal KIM error
-
-Self-explanatory. Check the output and kim.log file for more details.
-
-U: test_descriptor_string already allocated
-
-This should not happen. It likely indicates a bug in the pair_kim
-implementation.
+This is an internal error.  Contact the developers.
 
 */
diff --git a/src/KSPACE/pair_lj_long_coul_long.h b/src/KSPACE/pair_lj_long_coul_long.h
index 7a1d36b9b9..7a825b85d4 100644
--- a/src/KSPACE/pair_lj_long_coul_long.h
+++ b/src/KSPACE/pair_lj_long_coul_long.h
@@ -80,7 +80,7 @@ command-line option when running LAMMPS to see the offending line.
 
 W: Using largest cutoff for lj/long/coul/long
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Cutoffs missing in pair_style lj/long/coul/long
 
@@ -100,7 +100,7 @@ Self-explanatory.  Check the input script or data file.
 
 E: Invoking coulombic in pair style lj/coul requires atom attribute q
 
-UNDOCUMENTED
+The atom style defined does not have this attribute.
 
 E: Pair style requires a KSpace style
 
diff --git a/src/KSPACE/pppm.h b/src/KSPACE/pppm.h
index 76a5bdea19..7765ef9636 100644
--- a/src/KSPACE/pppm.h
+++ b/src/KSPACE/pppm.h
@@ -327,7 +327,7 @@ large a timestep, etc.
 
 E: Cannot (yet) use K-space slab correction with compute group/group for triclinic systems
 
-UNDOCUMENTED
+This option is not yet supported.
 
 E: Cannot (yet) use kspace_modify diff ad with compute group/group
 
diff --git a/src/KSPACE/pppm_disp.h b/src/KSPACE/pppm_disp.h
index e401211fe4..e509a4d8b2 100755
--- a/src/KSPACE/pppm_disp.h
+++ b/src/KSPACE/pppm_disp.h
@@ -515,6 +515,12 @@ E: Out of range atoms - cannot compute PPPMDisp
 
 UNDOCUMENTED
 
+
+
+
+
+
+
 U: Unsupported mixing rule in kspace_style pppm/disp for pair_style %s
 
 UNDOCUMENTED
diff --git a/src/KSPACE/pppm_old.h b/src/KSPACE/pppm_old.h
index 58e303c57b..758dd79a49 100644
--- a/src/KSPACE/pppm_old.h
+++ b/src/KSPACE/pppm_old.h
@@ -237,7 +237,8 @@ requested accuracy.
 
 E: PPPM order has been reduced to 0
 
-UNDOCUMENTED
+The auto-adjust of the order failed.  You will need to
+set the grid size and order directly via kspace_modify.
 
 E: KSpace accuracy must be > 0
 
@@ -245,7 +246,8 @@ The kspace accuracy designated in the input must be greater than zero.
 
 E: Cannot compute PPPM G
 
-UNDOCUMENTED
+The Ewald factor could not be computed for the current choice of
+grid size, cutoff, accuracy.
 
 E: Out of range atoms - cannot compute PPPM
 
@@ -265,6 +267,6 @@ large a timestep, etc.
 
 E: Cannot (yet) use K-space slab correction with compute group/group
 
-UNDOCUMENTED
+This option is not yet supported.
 
 */
diff --git a/src/MANYBODY/pair_comb3.h b/src/MANYBODY/pair_comb3.h
index fb4bda76ee..689d19aa69 100644
--- a/src/MANYBODY/pair_comb3.h
+++ b/src/MANYBODY/pair_comb3.h
@@ -282,36 +282,40 @@ Self-explanatory.  Check the input script or data file.
 
 E: Pair style COMB3 requires atom IDs
 
-UNDOCUMENTED
+This is a requirement to use this potential.
 
 E: Pair style COMB3 requires newton pair on
 
-UNDOCUMENTED
+See the newton command.  This is a restriction to use the COMB3
+potential.
 
 E: Pair style COMB3 requires atom attribute q
 
-UNDOCUMENTED
+The atom style defined does not have this attribute.
 
 E: All pair coeffs are not set
 
 All pair coefficients must be set in the data file or by the
 pair_coeff command before running a simulation.
 
-E: Cannot open COMB3 C library file \n
+E: Cannot open COMB3 C library file
 
-UNDOCUMENTED
+The extra lib.comb3 file for carbon cannot be opened.  Check that it
+exists.
 
 E: Cannot open COMB3 potential file %s
 
-UNDOCUMENTED
+The specified COMB potential file cannot be opened.  Check that the
+path and name are correct.
 
 E: Incorrect format in COMB3 potential file
 
-UNDOCUMENTED
+Incorrect number of words per line in the potential file.
 
 E: Illegal COMB3 parameter
 
-UNDOCUMENTED
+One or more of the coefficients defined in the potential file is
+invalid.
 
 E: Potential file has duplicate entry
 
@@ -329,48 +333,8 @@ There are too many neighbors of a single atom.  Use the neigh_modify
 command to increase the max number of neighbors allowed for one atom.
 You may also want to boost the page size.
 
-E: Error in vdw spline: inner radius > outter radius
-
-UNDOCUMENTED
-
-
-
-
-
-
-U: Pair style COMB requires atom IDs
-
-This is a requirement to use the AIREBO potential.
-
-U: Pair style COMB requires newton pair on
-
-See the newton command.  This is a restriction to use the COMB
-potential.
-
-U: Pair style COMB requires atom attribute q
+E: Error in vdw spline: inner radius > outer radius
 
 Self-explanatory.
 
-U: Cannot open COMB potential file %s
-
-The specified COMB potential file cannot be opened.  Check that the
-path and name are correct.
-
-U: Incorrect format in COMB potential file
-
-Incorrect number of words per line in the potential file.
-
-U: Illegal COMB parameter
-
-One or more of the coefficients defined in the potential file is
-invalid.
-
-U: Pair COMB charge %.10f with force %.10f hit min barrier
-
-Something is possibly wrong with your model.
-
-U: Pair COMB charge %.10f with force %.10f hit max barrier
-
-Something is possibly wrong with your model.
-
 */
diff --git a/src/MANYBODY/pair_lcbop.h b/src/MANYBODY/pair_lcbop.h
index 16ed0ac6d1..339b1bcd4d 100644
--- a/src/MANYBODY/pair_lcbop.h
+++ b/src/MANYBODY/pair_lcbop.h
@@ -177,107 +177,31 @@ command-line option when running LAMMPS to see the offending line.
 
 E: Incorrect args for pair coefficients
 
-UNDOCUMENTED
+Self-explanatory.  Check the input script or data file.
 
 E: Pair style LCBOP requires atom IDs
 
-UNDOCUMENTED
+This is a requirement to use the LCBOP potential.
 
 E: Pair style LCBOP requires newton pair on
 
-UNDOCUMENTED
+See the newton command.  This is a restriction to use the Tersoff
+potential.
 
 E: All pair coeffs are not set
 
-UNDOCUMENTED
+All pair coefficients must be set in the data file or by the
+pair_coeff command before running a simulation.
 
 E: Neighbor list overflow, boost neigh_modify one
 
-UNDOCUMENTED
+There are too many neighbors of a single atom.  Use the neigh_modify
+command to increase the max number of neighbors allowed for one atom.
+You may also want to boost the page size.
 
 E: Cannot open LCBOP potential file %s
 
-UNDOCUMENTED
-
-U: Variable name for thermo every does not exist
-
-Self-explanatory.
-
-U: Variable for thermo every is invalid style
-
-Only equal-style variables can be used.
-
-U: Variable name for dump every does not exist
-
-Self-explanatory.
-
-U: Variable for dump every is invalid style
-
-Only equal-style variables can be used.
-
-U: Variable name for restart does not exist
-
-Self-explanatory.
-
-U: Variable for restart is invalid style
-
-Only equal-style variables can be used.
-
-U: Dump every variable returned a bad timestep
-
-The variable must return a timestep greater than the current timestep.
-
-U: Restart variable returned a bad timestep
-
-The variable must return a timestep greater than the current timestep.
-
-U: Thermo every variable returned a bad timestep
-
-The variable must return a timestep greater than the current timestep.
-
-U: Reuse of dump ID
-
-A dump ID cannot be used twice.
-
-U: Could not find dump group ID
-
-A group ID used in the dump command does not exist.
-
-U: Invalid dump frequency
-
-Dump frequency must be 1 or greater.
-
-U: Invalid dump style
-
-The choice of dump style is unknown.
-
-U: Cound not find dump_modify ID
-
-Self-explanatory.
-
-U: Could not find undump ID
-
-A dump ID used in the undump command does not exist.
-
-U: Thermo_style command before simulation box is defined
-
-The thermo_style command cannot be used before a read_data,
-read_restart, or create_box command.
-
-U: New thermo_style command, previous thermo_modify settings will be lost
-
-If a thermo_style command is used after a thermo_modify command, the
-settings changed by the thermo_modify command will be reset to their
-default values.  This is because the thermo_modify commmand acts on
-the currently defined thermo style, and a thermo_style command creates
-a new style.
-
-U: Both restart files must have '%' or neither
-
-UNDOCUMENTED
-
-U: Both restart files must use MPI-IO or neither
-
-UNDOCUMENTED
+The specified LCBOP potential file cannot be opened.  Check that the
+path and name are correct.
 
 */
diff --git a/src/MANYBODY/pair_nb3b_harmonic.h b/src/MANYBODY/pair_nb3b_harmonic.h
index ac08424f54..47227e58de 100644
--- a/src/MANYBODY/pair_nb3b_harmonic.h
+++ b/src/MANYBODY/pair_nb3b_harmonic.h
@@ -77,11 +77,11 @@ Self-explanatory.  Check the input script or data file.
 
 E: Pair style nb3b/harmonic requires atom IDs
 
-UNDOCUMENTED
+This is a requirement to use this potential.
 
 E: Pair style nb3b/harmonic requires newton pair on
 
-UNDOCUMENTED
+See the newton command.  This is a restriction to use this potential.
 
 E: All pair coeffs are not set
 
@@ -90,15 +90,17 @@ pair_coeff command before running a simulation.
 
 E: Cannot open nb3b/harmonic potential file %s
 
-UNDOCUMENTED
+The specified potential file cannot be opened.  Check that the path
+and name are correct.
 
 E: Incorrect format in nb3b/harmonic potential file
 
-UNDOCUMENTED
+Incorrect number of words per line in the potential file.
 
 E: Illegal nb3b/harmonic parameter
 
-UNDOCUMENTED
+One or more of the coefficients defined in the potential file is
+invalid.
 
 E: Potential file has duplicate entry
 
@@ -110,45 +112,4 @@ E: Potential file is missing an entry
 The potential file for a SW or Tersoff potential does not have a
 needed entry.
 
-U: Pair style COMB requires atom IDs
-
-This is a requirement to use the AIREBO potential.
-
-U: Pair style COMB requires newton pair on
-
-See the newton command.  This is a restriction to use the COMB
-potential.
-
-U: Pair style COMB requires atom attribute q
-
-Self-explanatory.
-
-U: Cannot open COMB potential file %s
-
-The specified COMB potential file cannot be opened.  Check that the
-path and name are correct.
-
-U: Incorrect format in COMB potential file
-
-Incorrect number of words per line in the potential file.
-
-U: Illegal COMB parameter
-
-One or more of the coefficients defined in the potential file is
-invalid.
-
-U: Pair COMB charge %.10f with force %.10f hit min barrier
-
-Something is possibly wrong with your model.
-
-U: Pair COMB charge %.10f with force %.10f hit max barrier
-
-Something is possibly wrong with your model.
-
-U: Neighbor list overflow, boost neigh_modify one
-
-There are too many neighbors of a single atom.  Use the neigh_modify
-command to increase the max number of neighbors allowed for one atom.
-You may also want to boost the page size.
-
 */
diff --git a/src/MANYBODY/pair_tersoff_mod.h b/src/MANYBODY/pair_tersoff_mod.h
index 9b30bd4bee..d2c545b25c 100644
--- a/src/MANYBODY/pair_tersoff_mod.h
+++ b/src/MANYBODY/pair_tersoff_mod.h
@@ -82,33 +82,26 @@ class PairTersoffMOD : public PairTersoff {
 
 E: Cannot open Tersoff potential file %s
 
-UNDOCUMENTED
+The specified potential file cannot be opened.  Check that the
+path and name are correct.
 
 E: Incorrect format in Tersoff potential file
 
-UNDOCUMENTED
+Incorrect number of words per line in the potential file.
 
 E: Illegal Tersoff parameter
 
-UNDOCUMENTED
+One or more of the coefficients defined in the potential file is
+invalid.
 
 E: Potential file has duplicate entry
 
-UNDOCUMENTED
+The potential file for a SW or Tersoff potential has more than
+one entry for the same 3 ordered elements.
 
 E: Potential file is missing an entry
 
-UNDOCUMENTED
-
-U: Illegal ... command
-
-Self-explanatory.  Check the input script syntax and compare to the
-documentation for the command.  You can use -echo screen as a
-command-line option when running LAMMPS to see the offending line.
-
-U: Region union region ID does not exist
-
-One or more of the region IDs specified by the region union command
-does not exist.
+The potential file for a SW or Tersoff potential does not have a
+needed entry.
 
 */
diff --git a/src/MISC/pair_nm_cut.h b/src/MISC/pair_nm_cut.h
index c4f289a9d5..d155b89e85 100644
--- a/src/MISC/pair_nm_cut.h
+++ b/src/MISC/pair_nm_cut.h
@@ -66,71 +66,11 @@ command-line option when running LAMMPS to see the offending line.
 
 E: Incorrect args for pair coefficients
 
-UNDOCUMENTED
+Self-explanatory.  Check the input script or data file.
 
 E: All pair coeffs are not set
 
-UNDOCUMENTED
-
-U: Create_atoms command before simulation box is defined
-
-The create_atoms command cannot be used before a read_data,
-read_restart, or create_box command.
-
-U: Cannot create_atoms after reading restart file with per-atom info
-
-The per-atom info was stored to be used when by a fix that you
-may re-define.  If you add atoms before re-defining the fix, then
-there will not be a correct amount of per-atom info.
-
-U: Create_atoms region ID does not exist
-
-A region ID used in the create_atoms command does not exist.
-
-U: Invalid basis setting in create_atoms command
-
-UNDOCUMENTED
-
-U: Molecule template ID for create_atoms does not exist
-
-UNDOCUMENTED
-
-U: Molecule template for create_atoms has multiple molecules
-
-UNDOCUMENTED
-
-U: Invalid atom type in create_atoms command
-
-The create_box command specified the range of valid atom types.
-An invalid type is being requested.
-
-U: Create_atoms molecule must have coordinates
-
-UNDOCUMENTED
-
-U: Create_atoms molecule must have atom types
-
-UNDOCUMENTED
-
-U: Invalid atom type in create_atoms mol command
-
-UNDOCUMENTED
-
-U: Create_atoms molecule has atom IDs, but system does not
-
-UNDOCUMENTED
-
-U: Cannot create atoms with undefined lattice
-
-Must use the lattice command before using the create_atoms
-command.
-
-U: Too many total atoms
-
-See the setting for bigint in the src/lmptype.h file.
-
-U: No overlap of box and region for create_atoms
-
-Self-explanatory.
+All pair coefficients must be set in the data file or by the
+pair_coeff command before running a simulation.
 
 */
diff --git a/src/MOLECULE/pair_lj_cut_tip4p_cut.h b/src/MOLECULE/pair_lj_cut_tip4p_cut.h
index 354027769c..79da7bcb82 100644
--- a/src/MOLECULE/pair_lj_cut_tip4p_cut.h
+++ b/src/MOLECULE/pair_lj_cut_tip4p_cut.h
@@ -91,15 +91,16 @@ Self-explanatory.  Check the input script or data file.
 
 E: Pair style lj/cut/tip4p/cut requires atom IDs
 
-UNDOCUMENTED
+This is a requirement to use this potential.
 
 E: Pair style lj/cut/tip4p/cut requires newton pair on
 
-UNDOCUMENTED
+See the newton command.  This is a restriction to use this
+potential.
 
 E: Pair style lj/cut/tip4p/cut requires atom attribute q
 
-UNDOCUMENTED
+The atom style defined does not have this attribute.
 
 E: Must use a bond style with TIP4P potential
 
@@ -113,6 +114,7 @@ command.
 
 E: Water H epsilon must be 0.0 for pair style lj/cut/tip4p/cut
 
-UNDOCUMENTED
+This is because LAMMPS does not compute the Lennard-Jones interactions
+with these particles for efficiency reasons.
 
 */
diff --git a/src/MOLECULE/pair_tip4p_cut.h b/src/MOLECULE/pair_tip4p_cut.h
index c20d856aa3..f99e7744e8 100644
--- a/src/MOLECULE/pair_tip4p_cut.h
+++ b/src/MOLECULE/pair_tip4p_cut.h
@@ -86,15 +86,15 @@ Self-explanatory.  Check the input script or data file.
 
 E: Pair style tip4p/cut requires atom IDs
 
-UNDOCUMENTED
+This is a requirement to use this potential.
 
 E: Pair style tip4p/cut requires newton pair on
 
-UNDOCUMENTED
+See the newton command.  This is a restriction to use this potential.
 
 E: Pair style tip4p/cut requires atom attribute q
 
-UNDOCUMENTED
+The atom style defined does not have this attribute.
 
 E: Must use a bond style with TIP4P potential
 
diff --git a/src/MPIIO/restart_mpiio.cpp b/src/MPIIO/restart_mpiio.cpp
index 1e10bd3b6a..55935d09d3 100644
--- a/src/MPIIO/restart_mpiio.cpp
+++ b/src/MPIIO/restart_mpiio.cpp
@@ -45,7 +45,7 @@ void RestartMPIIO::openForRead(char *filename)
     char mpiErrorString[MPI_MAX_ERROR_STRING];
     int mpiErrorStringLength;
     MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-    sprintf(str,"Cannot open restart file for reading - mpi error: %s\n",
+    sprintf(str,"Cannot open restart file for reading - MPI error: %s",
             mpiErrorString);
     error->one(FLERR,str);
   }
@@ -65,7 +65,7 @@ void RestartMPIIO::openForWrite(char *filename)
     char mpiErrorString[MPI_MAX_ERROR_STRING];
     int mpiErrorStringLength;
     MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-    sprintf(str,"Cannot open restart file for writing - mpi error: %s\n",
+    sprintf(str,"Cannot open restart file for writing - MPI error: %s",
             mpiErrorString);
     error->one(FLERR,str);
   }
@@ -96,7 +96,7 @@ void RestartMPIIO::write(MPI_Offset headerOffset, int send_size, double *buf)
     char mpiErrorString[MPI_MAX_ERROR_STRING];
     int mpiErrorStringLength;
     MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-    sprintf(str,"Cannot set restart file size - mpi error: %s\n",
+    sprintf(str,"Cannot set restart file size - MPI error: %s",
             mpiErrorString);
     error->one(FLERR,str);
   }
@@ -109,7 +109,7 @@ void RestartMPIIO::write(MPI_Offset headerOffset, int send_size, double *buf)
     char mpiErrorString[MPI_MAX_ERROR_STRING];
     int mpiErrorStringLength;
     MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-    sprintf(str,"Cannot write to restart file - mpi error: %s\n",
+    sprintf(str,"Cannot write to restart file - MPI error: %s",
             mpiErrorString);
     error->one(FLERR,str);
   }
@@ -143,7 +143,7 @@ void RestartMPIIO::read(MPI_Offset chunkOffset, bigint chunkSize, double *buf)
     char mpiErrorString[MPI_MAX_ERROR_STRING];
     int mpiErrorStringLength;
     MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-    sprintf(str,"Cannot read from restart file - mpi error: %s\n",
+    sprintf(str,"Cannot read from restart file - MPI error: %s",
             mpiErrorString);
     error->one(FLERR,str);
   }
@@ -167,7 +167,7 @@ void RestartMPIIO::read(MPI_Offset chunkOffset, bigint chunkSize, double *buf)
       char mpiErrorString[MPI_MAX_ERROR_STRING];
       int mpiErrorStringLength;
       MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-      sprintf(str,"Cannot read from restart file - mpi error: %s\n",
+      sprintf(str,"Cannot read from restart file - MPI error: %s",
               mpiErrorString);
       error->one(FLERR,str);
     }
@@ -188,7 +188,7 @@ void RestartMPIIO::close()
     char mpiErrorString[MPI_MAX_ERROR_STRING];
     int mpiErrorStringLength;
     MPI_Error_string(err, mpiErrorString, &mpiErrorStringLength);
-    sprintf(str,"Cannot close restart file - mpi error: %s\n",mpiErrorString);
+    sprintf(str,"Cannot close restart file - MPI error: %s",mpiErrorString);
     error->one(FLERR,str);
   }
 }
diff --git a/src/MPIIO/restart_mpiio.h b/src/MPIIO/restart_mpiio.h
index c7cff9e6f3..e5174716ec 100644
--- a/src/MPIIO/restart_mpiio.h
+++ b/src/MPIIO/restart_mpiio.h
@@ -41,28 +41,34 @@ class RestartMPIIO  : protected Pointers {
 
 /* ERROR/WARNING messages:
 
-E: Cannot open restart file for reading - mpi error: %s\n
+E: Cannot open restart file for reading - MPI error: %s
 
-UNDOCUMENTED
+This error was generated by MPI when reading/writing an MPI-IO restart
+file.
 
-E: Cannot open restart file for writing - mpi error: %s\n
+E: Cannot open restart file for writing - MPI error: %s
 
-UNDOCUMENTED
+This error was generated by MPI when reading/writing an MPI-IO restart
+file.
 
-E: Cannot set restart file size - mpi error: %s\n
+E: Cannot set restart file size - MPI error: %s
 
-UNDOCUMENTED
+This error was generated by MPI when reading/writing an MPI-IO restart
+file.
 
-E: Cannot write to restart file - mpi error: %s\n
+E: Cannot write to restart file - MPI error: %s
 
-UNDOCUMENTED
+This error was generated by MPI when reading/writing an MPI-IO restart
+file.
 
-E: Cannot read from restart file - mpi error: %s\n
+E: Cannot read from restart file - MPI error: %s
 
-UNDOCUMENTED
+This error was generated by MPI when reading/writing an MPI-IO restart
+file.
 
-E: Cannot close restart file - mpi error: %s\n
+E: Cannot close restart file - MPI error: %s
 
-UNDOCUMENTED
+This error was generated by MPI when reading/writing an MPI-IO restart
+file.
 
 */
diff --git a/src/REPLICA/verlet_split.h b/src/REPLICA/verlet_split.h
index 6d07e7bbe6..586d52f598 100644
--- a/src/REPLICA/verlet_split.h
+++ b/src/REPLICA/verlet_split.h
@@ -77,6 +77,6 @@ command must be used.
 
 E: Verlet/split does not yet support TIP4P
 
-UNDOCUMENTED
+This is a current limitation.
 
 */
diff --git a/src/pair.h b/src/pair.h
index 635d74756d..96b63d4f72 100644
--- a/src/pair.h
+++ b/src/pair.h
@@ -249,7 +249,9 @@ infinity.
 
 W: Using a manybody potential with bonds/angles/dihedrals and special_bond exclusions
 
-UNDOCUMENTED
+This is likely not what you want to do.  The exclusion settings will
+eliminate neighbors in the neighbor list, which the manybody potential
+needs to calculated its terms correctly.
 
 E: All pair coeffs are not set
 
@@ -258,7 +260,7 @@ pair_coeff command before running a simulation.
 
 E: Pair style requres a KSpace style
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Pair style does not support pair_write
 
diff --git a/src/read_data.h b/src/read_data.h
index 6be56a4011..7ac51b068d 100644
--- a/src/read_data.h
+++ b/src/read_data.h
@@ -188,7 +188,8 @@ Pair Coeffs.
 
 E: Must define pair_style before PairIJ Coeffs
 
-UNDOCUMENTED
+Must use a pair_style command before reading a data file that defines
+PairIJ Coeffs.
 
 E: Invalid data file section: Bond Coeffs
 
@@ -305,11 +306,12 @@ A section of the data file cannot be read by LAMMPS.
 E: No atoms in data file
 
 The header of the data file indicated that atoms would be included,
-but they were not present.
+but they are not present.
 
 E: Needed molecular topology not in data file
 
-UNDOCUMENTED
+The header of the data file indicated bonds, angles, etc would be
+included, but they are not present.
 
 E: Needed bonus data not in data file
 
@@ -375,7 +377,8 @@ The data file header lists improper but no improper types.
 
 E: No molecule topology allowed with atom style template
 
-UNDOCUMENTED
+The data file cannot specify the number of bonds, angles, etc,
+because this info if inferred from the molecule templates.
 
 E: Did not assign all atoms correctly
 
@@ -422,18 +425,4 @@ The specified file cannot be opened.  Check that the path and name are
 correct. If the file is a compressed file, also check that the gzip
 executable can be found and run.
 
-U: Invalid atom ID in Atoms section of data file
-
-Atom IDs must be positive integers.
-
-U: Molecular data file has too many atoms
-
-These kids of data files are currently limited to a number
-of atoms that fits in a 32-bit integer.
-
-U: Needed topology not in data file
-
-The header of the data file indicated that bonds or angles or
-dihedrals or impropers would be included, but they were not present.
-
 */
diff --git a/src/read_dump.h b/src/read_dump.h
index 8da05acfaf..168acff1ce 100644
--- a/src/read_dump.h
+++ b/src/read_dump.h
@@ -131,7 +131,7 @@ Self-explanatory.
 
 E: Read_dump xyz fields do not have consistent scaling/wrapping
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: All read_dump x,y,z fields must be specified for scaled, triclinic coords
 
@@ -145,7 +145,7 @@ See the setting for bigint in the src/lmptype.h file.
 
 E: Read dump of atom property that isn't allocated
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Duplicate fields in read_dump command
 
@@ -156,8 +156,4 @@ E: If read_dump purges it cannot replace or trim
 These operations are not compatible.  See the read_dump doc
 page for details.
 
-U: Read_dump x,y,z fields do not have consistent scaling
-
-Self-explanatory.
-
 */
diff --git a/src/read_restart.cpp b/src/read_restart.cpp
index c0a9bac92e..978b2d2bc9 100644
--- a/src/read_restart.cpp
+++ b/src/read_restart.cpp
@@ -103,7 +103,7 @@ void ReadRestart::command(int narg, char **arg)
 
   if (multiproc && mpiioflag) 
     error->all(FLERR,
-               "Read restart MPI-IO output not allowed with '%' in filename");
+               "Read restart MPI-IO input not allowed with % in filename");
 
   if (mpiioflag) {
     mpiio = new RestartMPIIO(lmp);
diff --git a/src/read_restart.h b/src/read_restart.h
index 9652e5ae7f..a63f6c3dbb 100644
--- a/src/read_restart.h
+++ b/src/read_restart.h
@@ -82,13 +82,14 @@ E: Cannot read_restart after simulation box is defined
 The read_restart command cannot be used after a read_data,
 read_restart, or create_box command.
 
-E: Read restart MPI-IO output not allowed with '%' in filename
+E: Read restart MPI-IO input not allowed with % in filename
 
-UNDOCUMENTED
+This is because a % signifies one file per processor and MPI-IO
+creates one large file for all processors.
 
 E: Reading from MPI-IO filename when MPIIO package is not installed
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Cannot open restart file %s
 
@@ -207,8 +208,4 @@ E: Restart file byte ordering is not recognized
 
 UNDOCUMENTED
 
-U: Restart file version does not match LAMMPS version
-
-This may cause problems when reading the restart file.
-
 */
diff --git a/src/replicate.h b/src/replicate.h
index bdc35601e2..6769ffbeec 100644
--- a/src/replicate.h
+++ b/src/replicate.h
@@ -68,7 +68,7 @@ system.
 
 E: Replicated system atom IDs are too big
 
-UNDOCUMENTED
+See the setting for tagint in the src/lmptype.h file.
 
 E: Replicated system is too big
 
@@ -80,9 +80,4 @@ Atoms replicated by the replicate command were not assigned correctly
 to processors.  This is likely due to some atom coordinates being
 outside a non-periodic simulation box.
 
-U: Replicated molecular system atom IDs are too big
-
-See the setting for the allowed atom ID size in the src/lmptype.h
-file.
-
 */
diff --git a/src/variable.h b/src/variable.h
index c6c21ac3f1..13e80e6c6f 100644
--- a/src/variable.h
+++ b/src/variable.h
@@ -149,7 +149,7 @@ Check the file assigned to the variable.
 
 E: Atomfile variable could not read values
 
-UNDOCUMENTED
+Check the file assigned to the variable.
 
 E: Variable name must be alphanumeric or underscore characters
 
@@ -170,7 +170,7 @@ command.
 
 E: Next command must list all universe and uloop variables
 
-UNDOCUMENTED
+This is to insure they stay in sync.
 
 E: Invalid syntax in variable formula
 
@@ -256,7 +256,7 @@ in an equal-style variable.
 
 E: Atomfile-style variable in equal-style variable formula
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Mismatched variable in variable formula
 
@@ -371,11 +371,11 @@ Self-explanatory.
 
 E: Atomfile variable in equal-style variable formula
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Invalid variable style in special function next
 
-UNDOCUMENTED
+Only file-style or atomfile-style variables can be used with next().
 
 E: Indexed per-atom vector in variable formula without atom map
 
@@ -386,7 +386,7 @@ map command will force an atom map to be created.
 
 E: Variable uses atom property that isn't allocated
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Invalid atom vector in variable formula
 
@@ -416,18 +416,10 @@ correct.
 
 E: Cannot use atomfile-style variable unless atom map exists
 
-UNDOCUMENTED
+Self-explanatory.  See the atom_modify command to create a map.
 
 E: Invalid atom ID in variable file
 
-UNDOCUMENTED
-
-U: Afile variable could not read values
-
-UNDOCUMENTED
-
-U: Invalid variable in special function next
-
-Only file-style variables can be used with the next() function.
+Self-explanatory.  
 
 */
diff --git a/src/velocity.h b/src/velocity.h
index 3b01e50e53..62905e7f75 100644
--- a/src/velocity.h
+++ b/src/velocity.h
@@ -115,7 +115,7 @@ Self-explanatory.
 
 E: Velocity rigid used with non-rigid fix-ID
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Attempting to rescale a 0.0 temperature
 
@@ -123,7 +123,7 @@ Cannot rescale a temperature that is already 0.0.
 
 E: Cannot zero momentum of no atoms
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Could not find velocity temperature ID
 
@@ -137,16 +137,6 @@ temperature.
 
 E: Fix ID for velocity does not exist
 
-UNDOCUMENTED
-
-U: Cannot zero momentum of 0 atoms
-
-The collection of atoms for which momentum is being computed has no
-atoms.
-
-U: Use of velocity with undefined lattice
-
-If units = lattice (the default) for the velocity set or velocity ramp
-command, then a lattice must first be defined via the lattice command.
+Self-explanatory.
 
 */
diff --git a/src/write_data.h b/src/write_data.h
index afdf270ab3..4f1a7bd69e 100644
--- a/src/write_data.h
+++ b/src/write_data.h
@@ -59,7 +59,7 @@ class WriteData : protected Pointers {
 
 E: Write_data command before simulation box is defined
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Illegal ... command
 
@@ -69,10 +69,12 @@ command-line option when running LAMMPS to see the offending line.
 
 E: Atom count is inconsistent, cannot write data file
 
-UNDOCUMENTED
+The sum of atoms across processors does not equal the global number
+of atoms.  Probably some atoms have been lost.
 
 E: Cannot open data file %s
 
-UNDOCUMENTED
+The specified file cannot be opened.  Check that the path and name are
+correct.
 
 */
diff --git a/src/write_dump.h b/src/write_dump.h
index e4108a4732..7695d2117d 100644
--- a/src/write_dump.h
+++ b/src/write_dump.h
@@ -45,85 +45,6 @@ command-line option when running LAMMPS to see the offending line.
 
 E: Invalid dump style
 
-UNDOCUMENTED
-
-U: Too many total bits for bitmapped lookup table
-
-Table size specified via pair_modify command is too large.  Note that
-a value of N generates a 2^N size table.
-
-U: Cannot have both pair_modify shift and tail set to yes
-
-These 2 options are contradictory.
-
-U: Cannot use pair tail corrections with 2d simulations
-
-The correction factors are only currently defined for 3d systems.
-
-U: Using pair tail corrections with nonperiodic system
-
-This is probably a bogus thing to do, since tail corrections are
-computed by integrating the density of a periodic system out to
-infinity.
-
-U: Using a manybody potential with bonds/angles/dihedrals and special_bond exclusions
-
-UNDOCUMENTED
-
-U: All pair coeffs are not set
-
-All pair coefficients must be set in the data file or by the
-pair_coeff command before running a simulation.
-
-U: Pair style requres a KSpace style
-
-UNDOCUMENTED
-
-U: Pair style does not support pair_write
-
-The pair style does not have a single() function, so it can
-not be invoked by pair write.
-
-U: Invalid atom types in pair_write command
-
-Atom types must range from 1 to Ntypes inclusive.
-
-U: Invalid style in pair_write command
-
-Self-explanatory.  Check the input script.
-
-U: Invalid cutoffs in pair_write command
-
-Inner cutoff must be larger than 0.0 and less than outer cutoff.
-
-U: Cannot open pair_write file
-
-The specified output file for pair energies and forces cannot be
-opened.  Check that the path and name are correct.
-
-U: Bitmapped lookup tables require int/float be same size
-
-Cannot use pair tables on this machine, because of word sizes.  Use
-the pair_modify command with table 0 instead.
-
-U: Table inner cutoff >= outer cutoff
-
-You specified an inner cutoff for a Coulombic table that is longer
-than the global cutoff.  Probably not what you wanted.
-
-U: Too many exponent bits for lookup table
-
-Table size specified via pair_modify command does not work with your
-machine's floating point representation.
-
-U: Too many mantissa bits for lookup table
-
-Table size specified via pair_modify command does not work with your
-machine's floating point representation.
-
-U: Too few bits for lookup table
-
-Table size specified via pair_modify command does not work with your
-machine's floating point representation.
+The choice of dump style is unknown.
 
 */
diff --git a/src/write_restart.h b/src/write_restart.h
index ff5ed6b245..ff42f5d709 100644
--- a/src/write_restart.h
+++ b/src/write_restart.h
@@ -85,21 +85,22 @@ Self-explanatory.  Check the input script syntax and compare to the
 documentation for the command.  You can use -echo screen as a
 command-line option when running LAMMPS to see the offending line.
 
-E: Restart file MPI-IO output not allowed with '%' in filename
+E: Restart file MPI-IO output not allowed with % in filename
 
-UNDOCUMENTED
+This is because a % signifies one file per processor and MPI-IO
+creates one large file for all processors.
 
 E: Writing to MPI-IO filename when MPIIO package is not installed
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Cannot use write_restart fileper without % in restart file name
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Cannot use write_restart nfile without % in restart file name
 
-UNDOCUMENTED
+Self-explanatory.
 
 E: Atom count is inconsistent, cannot write restart file
 
diff --git a/src/MANYBODY/pair_comb3.cpp b/src/MANYBODY/pair_comb3.cpp
index 2d6bf9f9ef..37f87788bf 100644
--- a/src/MANYBODY/pair_comb3.cpp
+++ b/src/MANYBODY/pair_comb3.cpp
@@ -323,7 +323,7 @@ void PairComb3::read_lib()
     FILE *fp =  fopen("lib.comb3","r");
     if (fp == NULL) {
       char str[128];
-      sprintf(str,"Cannot open COMB3 C library file \n");
+      sprintf(str,"Cannot open COMB3 C library file");
       error->one(FLERR,str);
     }
 
@@ -2648,9 +2648,9 @@ void PairComb3::tables()
                
         rvdw[1][inty] = params[iparam_ij].vsig * 0.950;
 
         // radius check: outter radius vs. sigma
         if( rvdw[0][inty] > rvdw[1][inty] )
-          error->all(FLERR,"Error in vdw spline: inner radius > outter radius");
+          error->all(FLERR,"Error in vdw spline: inner radius > outer radius");
 
         rrc[0] = rvdw[1][inty];
 
@@ -2648,9 +2648,9 @@ void PairComb3::tables()
         rvdw[1][inty] = params[iparam_ij].vsig * 0.950;
 
-        // radius check: outter radius vs. sigma
+        // radius check: outer radius vs. sigma
         if( rvdw[0][inty] > rvdw[1][inty] )
-- 
GitLab